diff --git a/BuildUbuntu.md b/BuildUbuntu.md
index 5af6622..8db665c 100644
--- a/BuildUbuntu.md
+++ b/BuildUbuntu.md
@@ -1,108 +1,112 @@
-[![ART](logo.png)](Home)
-
-# Ubuntu build recipe for **ART**
-
-*(contributed by Danny Heijl)*
-
-## Prerequisites
-
-These instructions were tested on Ubuntu 20.04 and 22.04 (Linux Mint 20 and 21), so should work on any Debian based distro.
-
-- install the necessary development packages:
-
-```bash
-sudo apt install autoconf libtool
-sudo apt install git build-essential cmake curl pkg-config libgtk-3-dev libgtkmm-3.0-dev librsvg2-dev liblcms2-dev libfftw3-dev libiptcdata0-dev libtiff5-dev libcanberra-gtk3-dev
-```
-
-- If you want to use the latest gcc, you can install gcc-12 and g++12 first before building anything, as per <https://www.linuxcapable.com/install-gcc-compiler-build-essential-on-ubuntu-2>:
-
-```bash
-sudo add-apt-repository ppa:ubuntu-toolchain-r/test -y
-sudo apt update && sudo apt upgrade
-sudo apt install gcc-12 g++-12
-sudo update-alternatives --install /usr/bin/gcc gcc /usr/bin/gcc-12 100 --slave /usr/bin/g++ g++ /usr/bin/g++-12 --slave /usr/bin/gcov gcov /usr/bin/gcov-12
-sudo update-alternatives --install /usr/bin/gcc gcc /usr/bin/gcc-11 60 --slave /usr/bin/g++ g++ /usr/bin/g++-11 --slave /usr/bin/gcov gcov /usr/bin/gcov-11
-gcc –version
-sudo update-alternatives --config gcc
-```
-
-- For Canon Cr3 suport you need a recent **LibRaw** build, this is how you build the current LibRaw version from Github:
-  - clone and install latest libraw from github
-  - cd to the cloned LibRaw folder and build and install LibRaw:
-
-```bash
-autoreconf --install
-./configure
-sudo make install
-sudo ldconfig
-```
-
-- You’ll want the latest **liblensfun** too:
-  - clone it from Github, cd to the cloned lensfun folder and build it:
-
-```bash
-mkdir build
-cd build
-cmake -DCMAKE_BUILD_TYPE=Release ../
-make
-sudo make install
-sudo ldconfig
-```
-
-- You need a recent version of **exiv2 0.27**, ART does not compile with the **exiv2** “main” branch due to API changes: to get Canon CR3 support from exiv2 you have to use a **recent exiv2 0.27** version. (Without a recent exiv2 library linked in you would have to install **exiftool** for Canon CR3 support: `sudo apt install exiftool`.)
-
-  - clone and install exiv2 0.27 maintenance from github, and cd to to the cloned exiv2 folder:
-
-```bash
-mkdir build && cd build
-cmake -DCMAKE_BUILD_TYPE=Release -DEXIV2_ENABLE_BMFF=On ..
-cd ..
-cmake --build .
-ctest –verbose
-sudo apt remove exiv2 libexiv2-dev
-sudo make install
-```
-
-- ART needs MIMALLOC, so clone it from Github (<https://github.com/microsoft/mimalloc>) and build it:
-
-```bash
-mkdir -p out/release
-cd out/release
-cmake ../..
-make
-sudo make install
-sudo ldconfig
-```
-
-- Recent versions of ART include **OpenColorIO**, so clone the GitHub repo and build it:`
-
-```bash
-mkdir /tmp/ociobuild
-cd /tmp/ociobuild
-cmake -DOCIO_INSTALL_EXT_PACKAGES=ALL -DOCIO_BUILD_PYTHON=OFF ~/Documenten/GitHub/OpenColorIO/ *(path to OpenColorIO clone)*
-make -j 4
-sudo make install
-```
-
-## Building **ART**
-
-- download the build-art script (raw) from <https://bitbucket.org/agriggio/art/src/master/tools/build-art>
-
-- Make build-art executable and execute it:
-
-```bash
-chmod +x ./build-art
-./build-art
-```
-
-This will install ART in `programs/art`.
-  
-Rerunning the build-art script will update the source code from the git repository and rebuild ART.
-If Alberto changes something in the build options you may have to redownload build-art and reapply any needed changes to the build-art script.
-
-- To get the latest liblensfun data just run:
-
-```bash
-sudo lensfun-update-data
-```
\ No newline at end of file
+[![ART](logo.png)](Home)
+
+# Ubuntu build recipe for **ART**
+
+*(contributed by Danny Heijl)*
+
+May 21 2023: Updated for ART 1.20 and exiv2 0.28.x branch:
+
+- new exiv2 dependency libinih-dev
+
+## Prerequisites
+
+These instructions were tested on Ubuntu 20.04 and 22.04 (Linux Mint 20 and 21), so should work on any Debian based distro.
+They assume you want to use the latest and greatest versions of all dependencies. You could of course choose to use the "stable" released versions instead.
+
+- install the necessary development packages:
+
+```bash
+sudo apt install autoconf libtool
+sudo apt install git build-essential cmake curl pkg-config libgtk-3-dev libgtkmm-3.0-dev librsvg2-dev liblcms2-dev libfftw3-dev libiptcdata0-dev libtiff5-dev libcanberra-gtk3-dev libinih-dev
+```
+
+- If you want to use the latest gcc, you can install gcc-12 and g++12 first before building anything, as per <https://www.linuxcapable.com/install-gcc-compiler-build-essential-on-ubuntu-2>:
+
+```bash
+sudo add-apt-repository ppa:ubuntu-toolchain-r/test -y
+sudo apt update && sudo apt upgrade
+sudo apt install gcc-12 g++-12
+sudo update-alternatives --install /usr/bin/gcc gcc /usr/bin/gcc-12 100 --slave /usr/bin/g++ g++ /usr/bin/g++-12 --slave /usr/bin/gcov gcov /usr/bin/gcov-12
+sudo update-alternatives --install /usr/bin/gcc gcc /usr/bin/gcc-11 60 --slave /usr/bin/g++ g++ /usr/bin/g++-11 --slave /usr/bin/gcov gcov /usr/bin/gcov-11
+gcc –version
+sudo update-alternatives --config gcc
+```
+
+- For Canon Cr3 suport you need a recent **LibRaw** build, this is how you build the current LibRaw version from Github:
+  - clone and install latest libraw from github
+  - cd to the cloned LibRaw folder and build and install LibRaw:
+
+```bash
+autoreconf --install
+./configure
+sudo make install
+sudo ldconfig
+```
+
+- You’ll want the latest **liblensfun** too:
+  - clone it from Github, cd to the cloned lensfun folder and build it:
+
+```bash
+mkdir build
+cd build
+cmake -DCMAKE_BUILD_TYPE=Release ../
+make
+sudo make install
+sudo ldconfig
+```
+
+- As of ART 1.20 you can use the new **exiv2 0.28.x** branch, instead of exiv2 0.27.maintenance branch (ART does not compile with the **exiv2** “main” branch due to API changes, and to get Canon CR3 support from exiv2 you have to use a **recent exiv2** version. Without a recent exiv2 library linked in you would have to install **exiftool** for Canon CR3 support: `sudo apt install exiftool`.)
+
+  - clone and install exiv2 0.28.x from github, and cd to to the cloned exiv2 folder:
+
+```bash
+mkdir build && cd build
+cmake -DCMAKE_BUILD_TYPE=Release -DEXIV2_ENABLE_BMFF=On ..
+cmake --build .
+ctest –verbose
+sudo apt remove exiv2 libexiv2-dev
+sudo make install
+```
+
+- ART needs MIMALLOC, so clone it from Github (<https://github.com/microsoft/mimalloc>) and build it:
+
+```bash
+mkdir -p out/release
+cd out/release
+cmake ../..
+make
+sudo make install
+sudo ldconfig
+```
+
+- Recent versions of ART include **OpenColorIO**, so clone the GitHub repo and build it:`
+
+```bash
+mkdir /tmp/ociobuild
+cd /tmp/ociobuild
+cmake -DOCIO_INSTALL_EXT_PACKAGES=ALL -DOCIO_BUILD_PYTHON=OFF ~/Documenten/GitHub/OpenColorIO/ *(path to OpenColorIO clone)*
+make -j 4
+sudo make install
+```
+
+## Building **ART**
+
+- download the build-art script (raw) from <https://bitbucket.org/agriggio/art/src/master/tools/build-art>
+
+- Make build-art executable and execute it:
+
+```bash
+chmod +x ./build-art
+./build-art
+```
+
+This will install ART in `programs/art`.
+  
+Rerunning the build-art script will update the source code from the git repository and rebuild ART.
+If Alberto changes something in the build options you may have to redownload build-art and reapply any needed changes to the build-art script.
+
+- To get the latest liblensfun data just run:
+
+```bash
+sudo lensfun-update-data
+```
